@@ -1,7 +1,7 @@
 /*
  * This file is part of libsidplayfp, a SID player engine.
  *
- * Copyright 2011-2019 Leandro Nini <drfiemost@users.sourceforge.net>
+ * Copyright 2011-2021 Leandro Nini <drfiemost@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,9 +37,9 @@
 /*
  * Adjust these paths to point to existing ROM dumps
  */
-#define KERNAL_PATH "/usr/lib/vice/C64/kernal"
-#define BASIC_PATH "/usr/lib/vice/C64/basic"
-#define CHARGEN_PATH "/usr/lib/vice/C64/chargen"
+#define KERNAL_PATH "/usr/share/vice/C64/kernal"
+#define BASIC_PATH "/usr/share/vice/C64/basic"
+#define CHARGEN_PATH "/usr/share/vice/C64/chargen"
 
 void loadRom(const char* path, char* buffer)
 {
@@ -63,15 +63,17 @@ int main(int argc, char* argv[])
 
     sidplayfp m_engine;
 
-    char kernal[8192];
-    char basic[8192];
-    char chargen[4096];
+    char rom[8192];
 
-    loadRom(KERNAL_PATH, kernal);
-    loadRom(BASIC_PATH, basic);
-    loadRom(CHARGEN_PATH, chargen);
+    loadRom(KERNAL_PATH, rom);
+    m_engine.setKernal((const uint8_t*)rom);
+
+    loadRom(BASIC_PATH, rom);
+    m_engine.setBasic((const uint8_t*)rom);
+
+    loadRom(CHARGEN_PATH, rom);
+    m_engine.setChargen((const uint8_t*)rom);
 
-    m_engine.setRoms((const uint8_t*)kernal, (const uint8_t*)basic, (const uint8_t*)chargen);
     SidConfig config = m_engine.config();
     config.powerOnDelay = 0x1267;
 
@@ -113,6 +115,11 @@ int main(int argc, char* argv[])
                 {
                     config.ciaModel = SidConfig::MOS8521;
                 }
+                else
+                if (!strcmp(&argv[i][0], "4485"))
+                {
+                    config.ciaModel = SidConfig::MOS6526W4485;
+                }
             }
             if (!strcmp(&argv[i][1], "-vic"))
             {
